from Products.Archetypes.config import TOOL_NAME
from Products.Archetypes.utils import isFactoryContained
from Products.CMFCore.interfaces import ICatalogTool
from Products.CMFCore.utils import getToolByName


def permissionmanager_reindexObjectSecurity(self, skip_self=False):
    # Execute standard object reindexing.
    self._old_reindexObjectSecurity(skip_self=skip_self)

    # The standard indexing does not update catalog metadata.
    # We need to do that because we introduce security relevant
    # catalog metadata in this package.

    # In order to do that, we reindex the fast index "getId" of the
    # current context, so that we can use `update_metadata=True`.
    # We do not do that recursive because the metadata values
    # are non-recursive.
    if isFactoryContained(self):
        return
    at = getToolByName(self, TOOL_NAME, None)
    if at is None:
        return

    catalogs = [catalog for catalog in at.getCatalogsByType(self.meta_type)
                if ICatalogTool.providedBy(catalog)]

    for catalog in catalogs:
        catalog.reindexObject(self, idxs=['getId'], update_metadata=True)



from Products.Archetypes import CatalogMultiplex
from Products.CMFCore import CMFCatalogAware
from zope.i18nmessageid import MessageFactory
import csv


permission_manager_factory = MessageFactory('ftw.permissionmanager')


class excel_ger(csv.excel):
    """Extend csv library with custem dialect excel_ger"""
    delimiter = ';'
csv.register_dialect('excel_ger', excel_ger)


def initialize(context):
    """Initializer called when used as a Zope 2 product."""
    register_local_roles_index()


def register_local_roles_index():
    name = 'principal_with_local_roles'
    for klass in (CMFCatalogAware.CMFCatalogAware,
                  CatalogMultiplex.CatalogMultiplex):

        if name in klass._cmf_security_indexes:
            continue

        indexes = list(klass._cmf_security_indexes)
        indexes.append(name)
        klass._cmf_security_indexes = tuple(indexes)
